"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getGrantFromSubscriptionRequest = exports.grantRequestsEqual = exports.isTelemetryMessage = exports.isDeviceTwinMessage = exports.isD2CMessage = exports.isConnectionStateMessage = exports.printDevModeWarning = exports.cleanSubId = exports.deserializeSubscriberState = exports.deserializeTelemetrySubscriberState = exports.parseSubKey = exports.makeSubKey = void 0;
var DELIMITER = '___';
function makeSubKey() {
    var args = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        args[_i] = arguments[_i];
    }
    return args.filter(function (arg) { return !!arg; }).join(DELIMITER);
}
exports.makeSubKey = makeSubKey;
function parseSubKey(subscriberKey) {
    var _a = subscriberKey.split(DELIMITER), subscriberId = _a[0], deviceId = _a[1], telemetryKey = _a[2];
    return { subscriberId: subscriberId, deviceId: deviceId, telemetryKey: telemetryKey };
}
exports.parseSubKey = parseSubKey;
function deserializeTelemetrySubscriberState(subscriberId, state) {
    return Object.keys(state).reduce(function (obj, key) {
        var _a = parseSubKey(key), id = _a.subscriberId, deviceId = _a.deviceId, telemetryKey = _a.telemetryKey;
        if (subscriberId === id) {
            if (obj[deviceId]) {
                obj[deviceId].push(telemetryKey);
            }
            else {
                obj[deviceId] = [telemetryKey];
            }
        }
        return obj;
    }, {});
}
exports.deserializeTelemetrySubscriberState = deserializeTelemetrySubscriberState;
function deserializeSubscriberState(subscriberId, state) {
    return Object.keys(state).reduce(function (deviceIds, key) {
        var _a = parseSubKey(key), id = _a.subscriberId, deviceId = _a.deviceId;
        if (subscriberId === id) {
            deviceIds.push(deviceId);
        }
        return deviceIds;
    }, []);
}
exports.deserializeSubscriberState = deserializeSubscriberState;
function cleanSubId(id, subscribers) {
    return Object.keys(subscribers).reduce(function (nextSubs, subKey) {
        var subscriberId = parseSubKey(subKey).subscriberId;
        if (subscriberId !== id) {
            nextSubs[subKey] = subscribers[subKey];
        }
        return nextSubs;
    }, {});
}
exports.cleanSubId = cleanSubId;
function printDevModeWarning() {
    console.log("%c\n _____________________________________________________\n|                                                     |\n|                     Warning                         |\n|  You are using ux4iot-react in Development mode.    |\n|                                                     |\n|  Don't use this in production, follow the link for  |\n|  more information: https://bit.ly/3igAntF           |\n|_____________________________________________________|\n\t", 'color: red; font-weight: bold; font-size: 14px;');
}
exports.printDevModeWarning = printDevModeWarning;
function isConnectionStateMessage(message) {
    return message.connectionState !== undefined;
}
exports.isConnectionStateMessage = isConnectionStateMessage;
function isD2CMessage(message) {
    return !!message.message;
}
exports.isD2CMessage = isD2CMessage;
function isDeviceTwinMessage(message) {
    return !!message.deviceTwin;
}
exports.isDeviceTwinMessage = isDeviceTwinMessage;
function isTelemetryMessage(message) {
    return !!message.telemetry;
}
exports.isTelemetryMessage = isTelemetryMessage;
function grantRequestsEqual(g1, g2) {
    if (g1.type === g2.type &&
        g1.sessionId === g2.sessionId &&
        g1.deviceId === g2.deviceId) {
        switch (g1.type) {
            case 'desiredProperties':
            case 'deviceTwin':
            case 'connectionState':
            case 'd2cMessages':
                return true;
            case 'directMethod':
                return g1.directMethodName === g2.directMethodName;
            case 'telemetry':
                return g1.telemetryKey === g2.telemetryKey;
            default:
                return false;
        }
    }
    return false;
}
exports.grantRequestsEqual = grantRequestsEqual;
function getGrantFromSubscriptionRequest(subscriptionRequest) {
    var type = subscriptionRequest.type, sessionId = subscriptionRequest.sessionId, deviceId = subscriptionRequest.deviceId;
    var grantRequest = { sessionId: sessionId, deviceId: deviceId, type: type };
    switch (type) {
        case 'connectionState':
        case 'deviceTwin':
        case 'd2cMessages':
            return grantRequest;
        case 'telemetry': {
            var telemetryKey = subscriptionRequest.telemetryKey;
            return __assign(__assign({}, grantRequest), { telemetryKey: telemetryKey });
        }
        default:
            throw Error('No such grantType for subscriptionType');
    }
}
exports.getGrantFromSubscriptionRequest = getGrantFromSubscriptionRequest;
